#!/bin/sh

CAMID=D01
ROOTD=/home/uecdcm/nikon
JPEGD=${ROOTD}/jpgs

cd ${ROOTD}

# Current time info
YY0=`/bin/date "+%y"`
MO0=`/bin/date "+%m"`
DD0=`/bin/date "+%d"`
HH0=`/bin/date "+%H"`
MI0=`/bin/date "+%M"`
SS0=`/bin/date "+%S"`

# Spring and Autumn settings
SUNR=5
SUNS=19

# Summer settings
if [ ${MO0} -ge 5 -a ${MO0} -le 7 ]
then SUNR=4
     SUNS=20
fi

# Winter settings
if [ ${MO0} -le 1 -o ${MO0} -ge 11 ]
then SUNR=6
     SUNS=18
fi

if [ ${HH0} -lt ${SUNR} -o ${HH0} -ge ${SUNS} ]
then SHUTTERSPEED=50
     EXPOSURECOMPENSATION=5
     ISO=12
else SHUTTERSPEED=5
     EXPOSURECOMPENSATION=5
     ISO=1
fi

# Setup image size
IMAGESIZE=2
gphoto2 --set-config-index imagesize=${IMAGESIZE}
C_IMAGESIZE=`printf "%02d" $IMAGESIZE`
echo -n 'Image Size    ('${C_IMAGESIZE}') > '
gphoto2 --get-config imagesize | grep Current

# Setup image quality
IMAGEQUALITY=0
gphoto2 --set-config-index imagequality=${IMAGEQUALITY}
C_IMAGEQUALITY=`printf "%02d" $IMAGEQUALITY`
echo -n 'Image Quality ('${C_IMAGEQUALITY}') > '
gphoto2 --get-config imagequality | grep Current

# Setup shutter speed
gphoto2 --set-config-index shutterspeed=${SHUTTERSPEED}
C_SHUTTERSPEED=`printf "%02d" $SHUTTERSPEED`
echo -n 'Shutter Speed ('${C_SHUTTERSPEED}') > '
gphoto2 --get-config shutterspeed | grep Current

# Setup exposuretime
gphoto2 --set-config exposurecompensation=${EXPOSURECOMPENSATION}
C_EXPOSURECOMPENSATION=`printf "%02d" $EXPOSURECOMPENSATION`
echo -n 'Exposure      ('${C_EXPOSURECOMPENSATION}') > '
gphoto2 --get-config exposurecompensation | grep Current

# Setup ISO value
gphoto2 --set-config-index iso=${ISO}
C_ISO=`printf "%02d" $ISO`
echo -n 'ISO Value     ('${C_ISO}') > '
gphoto2 --get-config iso | grep Current

FNAME=${CAMID}_20${YY0}${MO0}${DD0}${HH0}${MI0}${SS0}_S${C_SHUTTERSPEED}_E${C_EXPOSURECOMPENSATION}_I${C_ISO}.jpg
mkdir -p ${JPEGD}/20${YY0}${MO0}${DD0}

MESG1=20${YY0}${MO0}${DD0}" "${HH0}":"${MI0}":"${SS0}" JST"
MESG2="SETG: "${C_SHUTTERSPEED}_E${C_EXPOSURECOMPENSATION}_I${C_ISO}

rm -f ${ROOTD}/*_20*.jpg
gphoto2 --capture-image-and-download --filename ${FNAME}

cp ${ROOTD}/${CAMID}_20*.jpg ${JPEGD}/20${YY0}${MO0}${DD0}/
convert -pointsize 100 -fill "#FFFFFF" +antialias -font Times-Roman -gravity South -annotate -950+50 "${MESG1}" ${ROOTD}/${CAMID}_20*.jpg ${ROOTD}/latest.jpg
scp ${ROOTD}/latest.jpg hosokawa@darndeb01.ice.uec.ac.jp:WWW/public/uecdcm/
